@@ -1,5 +1,19 @@
 #ifndef _PBL_H_LOADED
 
+/* I would love to include ApplicationSupport/HISupport/Pastboard.h here
+ * so that I could use type PasteboardFlavorFlags in pb_resp_t. But *&#@
+ * Apple does not let me include subframeworks, so I have to use type
+ * OptionBits from OSTypes.h, since that is what PastboardFlavorFlags is
+ * defined in terms of. I could have included
+ * ApplicationSupport/ApplicationSupport.h, but that drags in the world,
+ * and more to the point causes compile errors under Mac OS 10.3
+ * Panther, which I support (possibly through sheer, bone-headed
+ * stupidity).
+ */
+#include <Kernel/libkern/OSTypes.h>
+
+#define PB_FLAVOR_FLAGS OptionBits
+
 #include <CoreFoundation/CFBase.h>
 
 /* this could also credibly be "public.plain-text", but in point
@@ -36,7 +50,7 @@ typedef struct {
 typedef struct {
     unsigned long id;		/* id of item data is from */
     char *flavor;		/* flavor of data */
-    unsigned long flags;	/* flavor flags */
+    PB_FLAVOR_FLAGS flags;	/* flavor flags */
     unsigned char *data;	/* only returned if want_data is true */
     size_t size;		/* only returned if want_data is true */
 } pbl_resp_t;
@@ -89,7 +103,7 @@ OSStatus pbl_copy (
 	size_t size,
 	unsigned long id,
 	const char *pbflavor,
-	unsigned long flags
+	PB_FLAVOR_FLAGS flags
 	);
 
 /*
@@ -106,7 +120,7 @@ OSStatus pbl_paste (
 	const char *pbflavor,
 	unsigned char **data,
 	size_t *size,
-	unsigned long *flags
+	PB_FLAVOR_FLAGS *flags
 	);
 
 /*
